# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/CloudWatchLogs2Pandas',
                'doc_host': 'https://guyernest.github.io',
                'git_url': 'https://github.com/guyernest/CloudWatchLogs2Pandas',
                'lib_path': 'CloudWatchLogs2Pandas'},
  'syms': { 'CloudWatchLogs2Pandas.CloudWatchQuery': { 'CloudWatchLogs2Pandas.CloudWatchQuery.CloudWatchQuery': ( 'cloudwatchquery.html#cloudwatchquery',
                                                                                                                  'CloudWatchLogs2Pandas/CloudWatchQuery.py'),
                                                       'CloudWatchLogs2Pandas.CloudWatchQuery.CloudWatchQuery.__init__': ( 'cloudwatchquery.html#cloudwatchquery.__init__',
                                                                                                                           'CloudWatchLogs2Pandas/CloudWatchQuery.py'),
                                                       'CloudWatchLogs2Pandas.CloudWatchQuery.CloudWatchQuery.add_log_group': ( 'cloudwatchquery.html#cloudwatchquery.add_log_group',
                                                                                                                                'CloudWatchLogs2Pandas/CloudWatchQuery.py'),
                                                       'CloudWatchLogs2Pandas.CloudWatchQuery.CloudWatchQuery.get_df': ( 'cloudwatchquery.html#cloudwatchquery.get_df',
                                                                                                                         'CloudWatchLogs2Pandas/CloudWatchQuery.py'),
                                                       'CloudWatchLogs2Pandas.CloudWatchQuery.CloudWatchQuery.set_region': ( 'cloudwatchquery.html#cloudwatchquery.set_region',
                                                                                                                             'CloudWatchLogs2Pandas/CloudWatchQuery.py')},
            'CloudWatchLogs2Pandas.core': {'CloudWatchLogs2Pandas.core.foo': ('core.html#foo', 'CloudWatchLogs2Pandas/core.py')}}}